EndLayer

Struct EndLayer 

pub struct EndLayer<const END_S: usize>();
The end layer, this terminates the neural network linked list, just accepts the number of neurons in the final layer.

Type Parameters

  • END_S Number of neurons in the end layer.